package global;

import org.apache.beehive.netui.pageflow.*;
import org.apache.beehive.netui.pageflow.annotations.Jpf;

/**
 * The Global page flow is used to define actions which can be invoked by any other
 * page flow in a webapp. The Jpf.Catch annotation provides a global way to catch
 * unhandled exceptions by forwarding to an error page.
 */
@Jpf.Controller(
    catches={
       @Jpf.Catch(type=java.lang.Exception.class, method="handleException"),
       @Jpf.Catch(type=PageFlowException.class, method="handlePageFlowException")
    }
)
public class Global extends GlobalApp
{
   /**
    * Sample global action that will return to the default Controller.jpf in
    * the webapp root.
    */
    @Jpf.Action(
       forwards={
          @Jpf.Forward(name="home", path="/Controller.jpf")
       }
    )
    public Forward home()
    {
        return new Forward("home");
    }

    @Jpf.ExceptionHandler(
        forwards={
            @Jpf.Forward(name="errorPage", path="/error.jsp")
        }
    )
    protected Forward handleException(Exception ex, String actionName, String message, Object form)
    {
        System.err.print("[" + getRequest().getContextPath() + "] ");
        System.err.println("Unhandled exception caught in Global.app:");
        ex.printStackTrace();
        return new Forward("errorPage");
    }

    /** 
     * Handler for native page flow exceptions (e.g., ActionNotFoundException,
     * which is thrown when an unknown page flow action is requested). This handler
     * allows PageFlowExceptions to write informative error pages to the response.
     * To use the standard exception-handler for these exceptions, simply remove
     * this method and the Jpf.Catch annotation for PageFlowException.
     */
    @Jpf.ExceptionHandler
    public Forward handlePageFlowException(PageFlowException ex, String actionName, String message, Object form) 
        throws java.io.IOException
    { 
        ex.sendError(getRequest(), getResponse()); 
        return null; 
    } 
}
